@@ -2,7 +2,7 @@ from typing import Any, Dict, Optional
 
 from farcaster.models import *
 
-FARCASTER_API_BASE_URL = "https://api.farcaster.xyz/v2/"
+FARCASTER_API_BASE_URL = "https://api.warpcast.com/v2/"
 
 
 class ConfigurationParams(BaseModel):
